@@ -303,19 +303,21 @@ class MAFWBackend(AbstractBackend):
 
     def _close(self):
     
+	self.__current_position = -1
         self.__mafw.mafw_renderer_stop(hash(self.__renderer),
                                        self.__playback_cb,
                                        None)
 
-
     def _get_position(self):
+	self.__current_position = -1
         self.__mafw.mafw_renderer_get_position(hash(self.__renderer),
                                                self.__position_cb,
                                                None)
 
-        timeout = time.time() + 1                                       
-        while (time.time() < timeout and self.__current_position == -1):
-            gobject.timeout_add(10, lambda :False)  
+	timeout = time.time() + 1 
+	while (time.time() < timeout and self.__current_position == -1):
+		gobject.timeout_add(10, lambda :False) 
+		gobject.main_context_default().iteration(True)
 
         return (self.__current_position, self.__duration)
 
