@@ -153,6 +153,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 				self.player.close()
 			else:
 				self.player.stop()
+				time.sleep ( 1 )
 
 			if self.skip and self.playing:
 				self.onPlayBackEnded()
@@ -161,7 +162,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		self.player.play()
 
 	def onPlayBackEnded( self ): #EOF Reached, start next song.
-		if not self.state == 0: #Sometimes when skipping we get an EOF signal, sometimes we don't.  I use this so we don't skip twice.
+		if self.state == 0: #Sometimes when skipping we get an EOF signal, sometimes we don't.  I use this so we don't skip twice.
 			print "EOF called."
 			self.emit(QtCore.SIGNAL("PlayNext"))
 		else:
